pub fn incircle(a: Point2, b: Point2, c: Point2, d: Point2) -> CertifiedExpand description
Is d inside the circle through a, b, c?
Sign::Positive means inside when a, b, c are counter-clockwise.
Callers that cannot guarantee that orientation must normalise it first with
orient2d, because the sign of this determinant flips with it.
Always Certified::Certain.